@@ -217,8 +217,9 @@
                 var hashtags_length = 0;
                 for(var i in hashtags) {
                     var tag = hashtags[i];
-                    hashtags_length += tag.length + 2;
+                    hashtags_length += tag.length + 1;
                 }
+                hashtags_length += hashtags.length;
 
                 var text_max_length = (140 - url_length - hashtags_length);
                 if (text_max_length < 0)
@@ -226,10 +227,6 @@
                 else if(text_max_length > 120)
                     text_max_length = 120;
 
-                console.log("text: " + text_max_length)
-                console.log("url: " + url_length)
-                console.log("tags: " + hashtags_length)
-
                 text = abbreviateText(text, text_max_length);
 
                 var text = encodeURIComponent(text);
